@@ -26,6 +26,7 @@ from kamocli.utils import (
 log = logging.getLogger(__name__)
 
 from typer import Typer, Context, Argument, Option, echo, secho, confirm, edit
+
 app = Typer()
 
 
@@ -95,13 +96,14 @@ def clear(
 objects_app = Typer()
 app.add_typer(objects_app, name="objects", help="Manage kamo objects")
 
+
 @objects_app.command("list")
 def objects(
     ctx: Context,
     class_name: str = Option("", "-c", "--class", help="Filter by object class"),
     kamo_id: str = Option("", "-k", "--kamo_id", help="filter on kamo_id"),
     region_id: str = Option("", "-r", "--region_id", help="filter on region_id"),
-    num: int = Option(100, "-n", help="Maximum number of results")
+    num: int = Option(100, "-n", help="Maximum number of results"),
 ):
     """
     View list of all kamo objects in all regions
@@ -132,6 +134,7 @@ def objects(
     echo(tabulate(lst, headers=headers))
     echo("")
 
+
 @objects_app.command("report")
 def report(
     ctx: Context,
@@ -175,6 +178,7 @@ def report(
     echo(tabulate(sorted(lst), headers=headers))
     echo("")
 
+
 @objects_app.command("cleanup")
 def delete(
     ctx: Context,
@@ -213,18 +217,19 @@ def delete(
 object_app = Typer()
 app.add_typer(object_app, name="object", help="Manage a single kamo object")
 
+
 @object_app.callback(
     help="Object management",
     context_settings={"allow_extra_args": True, "ignore_unknown_options": True},
 )
 def cli(ctx: Context, kamo_id: str = Argument(..., help="Kamo ID of the object")):
     from urllib.parse import quote
+
     ctx.obj.kamo_id = quote(kamo_id)
 
+
 @object_app.command("delete")
-def delete(
-    ctx: Context
-):
+def delete(ctx: Context):
     """
     Delete the kamo object
     """
@@ -238,13 +243,13 @@ def delete(
     except ServerError as ex:
         abort(ex)
 
+
 regions_app = Typer()
 app.add_typer(regions_app, name="regions", help="Manage kamo regions")
 
+
 @object_app.command("view")
-def view_object(
-    ctx: Context
-):
+def view_object(ctx: Context):
     """
     View a kamo object
     """
@@ -270,10 +275,9 @@ def view_object(
         out("\n")
         region_report(ctx, region_id)
 
+
 @object_app.command("state")
-def state_object(
-    ctx: Context
-):
+def state_object(ctx: Context):
     """
     View a kamo object's state
     """
@@ -298,10 +302,7 @@ def state_object(
 
 
 @object_app.command("edit")
-def edit_object(
-    ctx: Context,
-    key: str = Option(None, "-k", "--key", help="Edit a specific key")
-):
+def edit_object(ctx: Context, key: str = Option(None, "-k", "--key", help="Edit a specific key")):
     """
     Edit a kamo object state directly
     """
@@ -343,6 +344,7 @@ def edit_object(
         else:
             abort(str(resp.json()))
 
+
 def region_report(ctx, region_id):
     out(f"Region {region_id}:")
     session = ctx.obj.session
@@ -365,6 +367,7 @@ def region_report(ctx, region_id):
         except ServerError:
             out(f"No Unreal server is currently handling region {region_id}")
 
+
 regions_app = Typer()
 app.add_typer(regions_app, name="regions", help="Manage kamo regions")
 
@@ -400,9 +403,7 @@ def list_regions(ctx: Context):
 def create_region(
     ctx: Context,
     region: str = Argument(..., help="Kamo ID of region to create"),
-    state: str = Option(
-        '{"handler": ""}', "-s", "--state", show_default=True, help="Region initial state"
-    ),
+    state: str = Option('{"handler": ""}', "-s", "--state", show_default=True, help="Region initial state"),
 ):
     """
     Create a new kamo region. Use a comma-separated list to create multiple identical regions
@@ -453,6 +454,7 @@ def delete_all_regions(
 region_app = Typer()
 app.add_typer(region_app, name="region", help="Manage a single kamo region")
 
+
 @region_app.callback(
     help="Region management",
     context_settings={"allow_extra_args": True, "ignore_unknown_options": True},
@@ -460,6 +462,7 @@ app.add_typer(region_app, name="region", help="Manage a single kamo region")
 def cli(ctx: Context, region: str = Argument(..., help="Kamo ID of region to view")):
     ctx.obj.region = region
 
+
 @region_app.command("view")
 def view_region(ctx: Context):
     """
@@ -503,7 +506,12 @@ def delete_region(
 
 
 @region_app.command("create-object")
-def region_create_object(ctx: Context, class_name: str, kamo_id: str = Option(None, "-k", "--kamo-id", help="Unique kamoID (optional)"), state: str = Option("{}", "-s", "--state", help="Initial kamo state for the object")):
+def region_create_object(
+    ctx: Context,
+    class_name: str,
+    kamo_id: str = Option(None, "-k", "--kamo-id", help="Unique kamoID (optional)"),
+    state: str = Option("{}", "-s", "--state", help="Initial kamo state for the object"),
+):
     """
     Create an object in the region
     """
@@ -556,7 +564,6 @@ def region_delete_objects_class(ctx: Context, class_name: str):
     success(f"Kamo objects with class {class_name} have been deleted in region {region}. Server response: {msg}")
 
 
-
 @region_app.command("objects")
 def region_objects(ctx: Context, class_name: str = Option("", "-c", "--class", help="Filter by object class")):
     """
