@@ -299,7 +299,7 @@ def shutdown_all(
     cnt = len(jobs)
     for job in jobs:
         job_url = url + "/" + str(job["job_id"])
-        _ = ctx.obj.session.patch(url, json={"status": "shutdown"})
+        _ = ctx.obj.session.patch(job_url, json={"status": "shutdown"})
 
     if is_wait:
         start_time = time.time()
