@@ -2,8 +2,9 @@ import click
 import logging
 import kamocli
 import requests
-import dateutil
+import dateutil.parser
 import json
+import datetime
 import time
 from time import sleep
 from kamocli.utils import dumps, abort, print_tab, fmt_date, check_tenant, success, out
@@ -146,10 +147,9 @@ def wait_for_nodes(ctx, node_ids):
 def find_nodes(ctx, tenant=None):
     resp = ctx.obj.session.get(ctx.obj.session.knode_url + "/nodes")
     resp.raise_for_status()
-    content = resp.json()
-    nodes = content["nodes"]
+    nodes = resp.json()
     if tenant:
-        nodes = [n for n in content["nodes"] if n.get("tenant") == tenant]
+        nodes = [n for n in nodes if n.get("tenant") == tenant]
     return nodes
 
 
@@ -165,7 +165,6 @@ def list_nodes(
         help="View all nodes on the server, not just for my tenant",
     ),
 ):
-
     """
     List Nodes
     """
@@ -185,13 +184,19 @@ def list_nodes(
             )
 
     node_list = []
-    columns = ["node_id", "status", "registered", "last_modified", "instance_type", "tenant"]
+    columns = ["node_id", "status", "create_date", "modified_date", "instance_type", "tenant", "ip_address"]
     for node in nodes:
         node_row = []
+        status = node["status"]
+        last_modified = dateutil.parser.parse(node["modified_date"])
+        if status == "running" and last_modified < datetime.datetime.utcnow() - datetime.timedelta(minutes=2):
+            status += " (offline)"
+
         for k in columns:
             v = node.get(k)
             v = fmt_date(v)
             if k == "status":
+                v = status
                 if v != "running":
                     v = click.style(v, fg="red")
             node_row.append(v)
