@@ -236,8 +236,9 @@ def find_builds(ctx):
 def find_nodes(ctx):
     url = ctx.obj.session.knode_url + f"/nodes"
     resp = ctx.obj.session.get(url)
+    resp.raise_for_status()
     ret = {}
-    for node in resp.json()["nodes"]:
+    for node in resp.json():
         ret[node["node_id"]] = node
     return ret
 
@@ -281,7 +282,7 @@ def get_builds_from_s3_url(url, num=10):
             abort(f"You do not have access to {bucket_name}. Please review your AWS credentials")
     paths.sort(reverse=True)
     builds = []
-    for p in paths[:num]:
+    for p in paths:
         key = urljoin(p, buildinfo_filename)
         obj = s3.Object(bucket_name, key)
         f = BytesIO()
@@ -299,6 +300,8 @@ def get_builds_from_s3_url(url, num=10):
             logger.warning("Buildinfo file in {} has an invalid version {} and is excluded", s3_path, v)
             continue
         builds.append(c)
+        if len(builds) >= num:
+            break
     versions = {}
     builds.sort(key=itemgetter("version"), reverse=True)
     for build in builds:
